@@ -6,10 +6,11 @@ use warnings;
 
 use 5.008;
 
+our $VERSION = '0.13';
+
 BEGIN    {
     use Exporter ();
-    use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.13';
+    use vars qw (@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
     @ISA         = qw (Exporter);
     @EXPORT      = qw ();
     @EXPORT_OK   = qw ( align);
@@ -309,7 +310,7 @@ Text::Aligner
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -346,6 +347,14 @@ the screen.
 
 =head1 NAME
 
+Text::Aligner
+
+=head1 VERSION
+
+version 0.14
+
+=head1 NAME
+
 Text::Aligner - module to align text.
 
 =head1 ALIGNMENT
@@ -479,6 +488,18 @@ Shlomi Fish <shlomif@cpan.org>
 
 This software is Copyright (c) 2002 by Anno Siegel.
 
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2002 by Anno Siegel.
+
 This is free software, licensed under:
 
   The MIT (X11) License
